==> tine20-allinone_2020.03.4.tar.bz2: Crm/js/Crm-lang-ca-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Crm **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Crm'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2017-09-28 09:49+0000\nLast-Translator: sstamer <s.stamer@metaways.de>\nLanguage-Team: Catalan (http://www.transifex.com/tine20/tine20/language/ca/)\nLanguage: ca\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "All leads"
: "Tots els clients potencials"

, "Default Lead List"
: ""

, "The default list for new leads"
: ""

, "Get Notification E-mails"
: ""

, "The level of actions you want to be notified about."
: "El nivell de les accions sobre les quals voleu que se us notifiqui."

, "Send Notifications e-mails for own actions"
: ""

, "Get notifications e-mails for actions you did yourself"
: ""

, "Send Notifications e-mails to responsible"
: ""

, "Get notifications e-mails for action to responsible"
: ""

, "Send Notifications e-mails to customer"
: ""

, "Get notifications e-mails for action to customer"
: ""

, "Send Notifications e-mails to partner"
: ""

, "Get notifications e-mails for action to partner"
: ""

, "Default Favorite"
: "Preferit per defecte"

, "The default favorite which is loaded on crm startup"
: "El preferit per defecte que es carrega a l'inici del crm"

, "New Lead"
: ""

, "Tags"
: "Etiquetes"

, "Lead name"
: "Nom del client potencial"

, "Responsible"
: "Responsable"

, "Partner"
: "Col·laborador"

, "Customer"
: "Client"

, "Leadstate"
: "Estat"

, "Leadtype"
: "Tipus"

, "Leadsource"
: "Font"

, "Probability"
: "Probabilitat"

, "Turnover"
: "Volum de negoci"

, "Estimated end"
: "Finalització estimada"

, "Probable Turnover"
: "Volum de negoci probable"

, "Resubmission Date"
: ""

, "Import leads"
: ""

, "Contact"
: "Contacte"

, "CRM Role"
: "Rol CRM"

, "Tasks"
: "Tasques"

, "No Tasks to display"
: "Cap tasca a mostrar"

, "Summary"
: "Resum"

, "Add a task..."
: "Afegeix una tasca..."

, "Due Date"
: "Data de venciment"

, "Priority"
: "Prioritat"

, "Percent"
: "Percentatge"

, "Status"
: "Estat"

, "Organizer"
: ""

, "Add new {0}"
: "Afegeix un nou {0}"

, "Unlink {0}"
: "Desenllaça {0}"

, "Unlink selected {0}"
: "Desenllaça el {0} seleccionat"

, "Edit {0}"
: "Edita {0}"

, "Edit selected {0}"
: "Edita el {0} seleccionat"

, "Please choose the Lead to add the contacts to"
: ""

, "Please select the attenders' role"
: ""

, "Lead, Leads"
: [
  "Client potencial"
 ,"Clients potencials"

]
, "Select Lead"
: ""

, "Role"
: "Rol"

, "Select Role"
: ""

, "Adding {0} contacts to lead"
: ""

, "Phone"
: "Telèfon"

, "Mobile"
: "Mòbil"

, "Fax"
: "Fax"

, "E-Mail"
: "Correu electrònic"

, "Web"
: "Web"

, "Street"
: ""

, "Postalcode"
: ""

, "City"
: ""

, "Start"
: "Inici"

, "Change type to Customer"
: "Canvia el tipus a Client"

, "Change type to Responsible"
: "Canvia el tipus a Responsable"

, "Change type to Partner"
: "Canvia el tipus a Col·laborador"

, "Change contact type"
: "Canvia el tipus de contacte"

, "Search for Contacts to add ..."
: "Cerca contactes a afegir ..."

, "Name"
: "Nom"

, "Address"
: "Adreça"

, "Data"
: "Informació"

, "Cellphone"
: "Mòbil"

, "End"
: "Finalització"

, "You do not have the run right for the Tasks application or it is not activated."
: "No disposeu dels permisos per a executar l'aplicació Tasques o bé aquesta no es troba activada."

, "Products"
: "Productes"

, "You do not have the run right for the Sales application or it is not activated."
: "No disposeu dels permisos per a executar l'aplicació Vendes o bé aquesta no es troba activada."

, "Enter lead name"
: ""

, "Expected turnover"
: "Volum de negoci previst"

, "Description"
: "Descripció"

, "Enter description"
: "Introduïu una descripció"

, "lead list, lead lists"
: [
  "llista de clients potencials"
 ,"llistes de clients potencials"

]
, "lead lists"
: "llistes de clients potencials"

, "Quick Search"
: ""

, "Last Modified Time"
: ""

, "Last Modified By"
: ""

, "Creation Time"
: "Data de creació"

, "Created By"
: ""

, "X Lead"
: ""

, "Archived"
: ""

, "Product"
: "Producte"

, "Price"
: "Preu"

, "Quantity"
: "Quantitat"

, "Search for Products to add ..."
: "Cerca productes a afegir ..."

, "All leads I have read grants for"
: "Tots els clients potencials sobre els quals tenc permís de lectura"

, "Last modified by me"
: ""

, "All leads that I have last modified"
: ""

, "My leads"
: ""

, "All leads that I am responsible for"
: ""

, "Leads with overdue tasks"
: ""

, "Lead States Available"
: ""

, "Possible lead status, with their associated turnover probabilities. If a status is flagged, leads with this status are treated as closed."
: ""

, "open"
: "obert"

, "contacted"
: "contactat"

, "waiting for feedback"
: "esperant resposta"

, "quote sent"
: "pressupost enviat"

, "accepted"
: "acceptat"

, "lost"
: "perdut"

, "Lead Sources Available"
: ""

, "Possible lead sources. If a source is flagged as archived, leads of this source are treated as closed."
: ""

, "Lead Types Available"
: ""

, "Possible lead types."
: ""

, "Reseller"
: "Distribuïdor"

, "Enabled Features"
: ""

, "Enabled Features in CRM Application."
: ""

, "Lead Import"
: ""

, "Add new task on lead import"
: ""

, "Automatically creates a task for the responsible person if a new lead is imported."
: ""

, "Send notification e-mail on lead import"
: ""

, "Sends an e-mail to all responsible persons for the imported leads."
: ""

, "Lead duplicate check fields"
: ""

, "These fields are checked when a new lead is created. If a record with the same data in the fields is found, a duplicate exception is thrown."
: ""

, "State"
: "Estat"

, "Source"
: "Font"

, "Scheduled end"
: "Finalització prevista"

, "Folder"
: "Carpeta"

, "Updated by"
: "Actualitzat per"

, "Updated Fields:"
: "Camps actualitzats:"

, "'%s' changed from '%s' to '%s'."
: ""

, "Lead %s has been changed"
: "S'ha modificat el client potencial %s"

, "Lead %s has been deleted"
: ""

, "Lead %s has been created"
: ""

, "Task"
: ""

, "Lead Data"
: "Dades del client potencial"

, "End Scheduled"
: "Finalització prevista"

, "Contacts"
: "Contactes"

, "Telephone"
: "Telèfon"

, "Email"
: "Correu electrònic"

, "low"
: "baixa"

, "normal"
: "normal"

, "high"
: "alta"

, "urgent"
: "urgent"

, "Lead CSV import"
: ""

, "Import list (###CURRENTDATE###)"
: ""

, "Leads imported on ###CURRENTDATE### at ###CURRENTTIME### by ###USERFULLNAME###"
: ""

, "Edit new lead"
: ""

, "The following leads have just been imported into lead list %s"
: ""

, "%s new leads have been imported"
: ""

, "manage shared lead folders"
: "gestiona les carpetes de clients potencials compartides"

, "Create new shared lead folders"
: "Crea noves carpetes de clients potencials compartides"

, "manage shared leads favorites"
: "gestiona preferits de clients potencials compartits"

, "Create or update shared leads favorites"
: "Crea o actualitza preferits de clients potencials compartits"




, "Lead"
: "Client potencial"

, "lead list"
: "llista de clients potencials"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-allinone_2021.12.1.tar.bz2: Crm/js/Crm-lang-ca-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Crm **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Crm'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2020-05-11 11:49+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Catalan (http://www.transifex.com/tine20/tine20/language/ca/)\nLanguage: ca\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Customer"
: "Client"

, "Partner"
: "Col·laborador"

, "Phone"
: "Telèfon"

, "Mobile"
: "Mòbil"

, "Fax"
: "Fax"

, "E-Mail"
: "Correu electrònic"

, "Web"
: "Web"

, "Street"
: ""

, "Postalcode"
: ""

, "City"
: ""

, "Status"
: "Estat"

, "Start"
: "Inici"

, "Estimated end"
: "Finalització estimada"

, "Leadtype"
: "Tipus"

, "Leadsource"
: "Font"

, "Tags"
: "Etiquetes"

, "Lead name"
: "Nom del client potencial"

, "Responsible"
: "Responsable"

, "Leadstate"
: "Estat"

, "Probability"
: "Probabilitat"

, "Turnover"
: "Volum de negoci"

, "End"
: "Finalització"

, "Probable Turnover"
: "Volum de negoci probable"

, "Resubmission Date"
: ""

, "Import leads"
: ""

, "Add new {0}"
: "Afegeix un nou {0}"

, "Unlink {0}"
: "Desenllaça {0}"

, "Unlink selected {0}"
: "Desenllaça el {0} seleccionat"

, "Edit {0}"
: "Edita {0}"

, "Edit selected {0}"
: "Edita el {0} seleccionat"

, "New Lead"
: ""

, "Products"
: "Productes"

, "Product"
: "Producte"

, "Description"
: "Descripció"

, "Price"
: "Preu"

, "Quantity"
: "Quantitat"

, "Search for Products to add ..."
: "Cerca productes a afegir ..."

, "1"
: ""

, "Notifications are disabled"
: ""

, "Send Notification?"
: ""

, "Changes to this lead might send notifications. Press the button \"Notifcation are enabled\" to switch to \"Notification are disabled\""
: ""

, "Tasks"
: "Tasques"

, "You do not have the run right for the Tasks application or it is not activated."
: "No disposeu dels permisos per a executar l'aplicació Tasques o bé aquesta no es troba activada."

, "You do not have the run right for the Sales application or it is not activated."
: "No disposeu dels permisos per a executar l'aplicació Vendes o bé aquesta no es troba activada."

, "Lead, Leads"
: [
  "Client potencial"
 ,"Clients potencials"

]
, "Enter lead name"
: ""

, "Expected turnover"
: "Volum de negoci previst"

, "Enter description"
: "Introduïu una descripció"

, "lead list, lead lists"
: [
  "llista de clients potencials"
 ,"llistes de clients potencials"

]
, "lead lists"
: "llistes de clients potencials"

, "Quick Search"
: ""

, "Last Modified Time"
: ""

, "Last Modified By"
: ""

, "Creation Time"
: "Data de creació"

, "Created By"
: ""

, "X Lead"
: ""

, "read-only"
: ""

, "Archived"
: ""

, "Contact"
: "Contacte"

, "CRM Role"
: "Rol CRM"

, "Change type to Customer"
: "Canvia el tipus a Client"

, "Change type to Responsible"
: "Canvia el tipus a Responsable"

, "Change type to Partner"
: "Canvia el tipus a Col·laborador"

, "Change contact type"
: "Canvia el tipus de contacte"

, "Search for Contacts to add ..."
: "Cerca contactes a afegir ..."

, "Name"
: "Nom"

, "Address"
: "Adreça"

, "Data"
: "Informació"

, "Cellphone"
: "Mòbil"

, "Role"
: "Rol"

, "Please choose the Lead to add the contacts to"
: ""

, "Please select the attenders' role"
: ""

, "Select Lead"
: ""

, "Select Role"
: ""

, "Adding {0} contacts to lead"
: ""

, "No Tasks to display"
: "Cap tasca a mostrar"

, "Summary"
: "Resum"

, "Add a task..."
: "Afegeix una tasca..."

, "Due Date"
: "Data de venciment"

, "Priority"
: "Prioritat"

, "Percent"
: "Percentatge"

, "Organizer"
: ""

, "All leads"
: "Tots els clients potencials"

, "Default Lead List"
: ""

, "The default list for new leads"
: ""

, "Get Notification E-mails"
: ""

, "The level of actions you want to be notified about."
: "El nivell de les accions sobre les quals voleu que se us notifiqui."

, "Send Notifications e-mails for own actions"
: ""

, "Get notifications e-mails for actions you did yourself"
: ""

, "Default Favorite"
: "Preferit per defecte"

, "The default favorite which is loaded on crm startup"
: "El preferit per defecte que es carrega a l'inici del crm"

, "controls sending notification of Leads"
: ""

, "send notification)description"
: ""

, "send notification to all access container"
: ""

, "send notification to responsible"
: ""

, "send notification to responsible)description"
: ""

, "send notification to customer"
: ""

, "send notification to partner"
: ""

, "Lead States Available"
: ""

, "Possible lead status, with their associated turnover probabilities. If a status is flagged, leads with this status are treated as closed."
: ""

, "open"
: "obert"

, "contacted"
: "contactat"

, "waiting for feedback"
: "esperant resposta"

, "quote sent"
: "pressupost enviat"

, "accepted"
: "acceptat"

, "lost"
: "perdut"

, "Lead Sources Available"
: ""

, "Possible lead sources. If a source is flagged as archived, leads of this source are treated as closed."
: ""

, "Lead Types Available"
: ""

, "Possible lead types."
: ""

, "Reseller"
: "Distribuïdor"

, "Enabled Features"
: ""

, "Enabled Features in CRM Application."
: ""

, "Lead Import"
: ""

, "Lead Notification Confirmation"
: ""

, "Add new task on lead import"
: ""

, "Automatically creates a task for the responsible person if a new lead is imported."
: ""

, "Send notification e-mail on lead import"
: ""

, "Sends an e-mail to all responsible persons for the imported leads."
: ""

, "Lead duplicate check fields"
: ""

, "These fields are checked when a new lead is created. If a record with the same data in the fields is found, a duplicate exception is thrown."
: ""

, "Lead Data"
: "Dades del client potencial"

, "End Scheduled"
: "Finalització prevista"

, "Contacts"
: "Contactes"

, "Telephone"
: "Telèfon"

, "Email"
: "Correu electrònic"

, "low"
: "baixa"

, "normal"
: "normal"

, "high"
: "alta"

, "urgent"
: "urgent"

, "CSV all data"
: ""

, "Lead CSV import"
: ""

, "Import list (###CURRENTDATE###)"
: ""

, "Leads imported on ###CURRENTDATE### at ###CURRENTTIME### by ###USERFULLNAME###"
: ""

, "Edit new lead"
: ""

, "The following leads have just been imported into lead list %s"
: ""

, "%s new leads have been imported"
: ""

, "GENDER_Lead"
: ""

, "Show Closed"
: ""

, "Task"
: ""

, "State"
: "Estat"

, "Source"
: "Font"

, "Scheduled end"
: "Finalització prevista"

, "Folder"
: "Carpeta"

, "Updated by"
: "Actualitzat per"

, "Updated Fields:"
: "Camps actualitzats:"

, "'%s' changed from '%s' to '%s'."
: ""

, "Lead %s has been changed"
: "S'ha modificat el client potencial %s"

, "Lead %s has been deleted"
: ""

, "Lead %s has been created"
: ""

, "This Lead state is set to read-only therefore updating this Lead is not possible."
: ""

, "All leads I have read grants for"
: "Tots els clients potencials sobre els quals tenc permís de lectura"

, "Last modified by me"
: ""

, "All leads that I have last modified"
: ""

, "My leads"
: ""

, "All leads that I am responsible for"
: ""

, "Leads with overdue tasks"
: ""

, "manage shared lead folders"
: "gestiona les carpetes de clients potencials compartides"

, "Create new shared lead folders"
: "Crea noves carpetes de clients potencials compartides"

, "manage shared leads favorites"
: "gestiona preferits de clients potencials compartits"

, "Create or update shared leads favorites"
: "Crea o actualitza preferits de clients potencials compartits"




, "Lead"
: "Client potencial"

, "lead list"
: "llista de clients potencials"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
